fs5_to_fslr: fsaverage5 to fslr

View source: R/conversion_functions.R

fs5_to_fslrR Documentation

fsaverage5 to fslr

Description

Remaps vertex-wise surface data in fsaverage5 space to fslr space using the nearest neighbor approach

Usage

fs5_to_fslr(surf_data)

Arguments

surf_data

A N x V matrix object containing the surface data (N row for each subject, V for each vertex), in fsaverage5 (20484 vertices) space. See also SURFvextract() output format.

Value

A matrix object containing vertex-wise surface data mapped in fslr space

See Also

fslr_to_fs5

Examples

CTv = runif(20484,min=0, max=100);
CTv_fslr = fs5_to_fslr(CTv);

VertexWiseR documentation built on June 25, 2026, 9:06 a.m.