hip_points_cells: points and cells data required to build the hippocampus...

hip_points_cellsR Documentation

points and cells data required to build the hippocampus surface template

Description

points and cells data required to build the hippocampus surface template

Usage

hip_points_cells

Format

hip_points_cells

A list object with two data frame objects:

vertices

data frame with 7262 rows (vertices), 3 columns (MNI coordinates X, Y, Z)

vertices

data frame with 14266 rows (vertices), 3 columns (vertices of all unique triangles

vertices

data frame with 7262 rows (vertices), 3 columns (MNI coordinates X, Y, Z for unfolded hippocampal surface)


VertexWiseR documentation built on June 25, 2026, 9:06 a.m.