fsaverage5 to fslr
fs5_to_fslr.RdRemaps vertex-wise surface data in fsaverage5 space to fslr space using the nearest neighbor approach
Examples
CTv = runif(20484,min=0, max=100);
CTv_fslr = fs5_to_fslr(CTv);

fs5_to_fslr.RdRemaps vertex-wise surface data in fsaverage5 space to fslr space using the nearest neighbor approach
CTv = runif(20484,min=0, max=100);
CTv_fslr = fs5_to_fslr(CTv);