View source: R/conversion_functions.R
| fs5_to_fslr | R Documentation |
Remaps vertex-wise surface data in fsaverage5 space to fslr space using the nearest neighbor approach
fs5_to_fslr(surf_data)
surf_data |
A N x V matrix object containing the surface data (N row for each subject, V for each vertex), in fsaverage5 (20484 vertices) space. See also SURFvextract() output format. |
A matrix object containing vertex-wise surface data mapped in fslr space
fslr_to_fs5
CTv = runif(20484,min=0, max=100);
CTv_fslr = fs5_to_fslr(CTv);
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.