View source: R/conversion_functions.R
| fslr_to_fs5 | R Documentation |
Remaps vertex-wise surface data in fslr space to fsaverage5 space using the nearest neighbor approach
fslr_to_fs5(surf_data)
surf_data |
A N x V matrix object containing the surface data (N row for each subject, V for each vertex), in fslr (64984 vertices) space. See also SURFvextract() output format. |
A matrix object containing vertex-wise surface data mapped in fsaverage5 space
fs5_to_fslr
surf_data = runif(64984,min=0, max=100);
fs5_data=fslr_to_fs5(surf_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.